"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Divider_1 = tslib_1.__importDefault(require("@material-ui/core/Divider"));
const IconButton_1 = tslib_1.__importDefault(require("@material-ui/core/IconButton"));
const Menu_1 = tslib_1.__importDefault(require("@material-ui/core/Menu"));
const MenuItem_1 = tslib_1.__importDefault(require("@material-ui/core/MenuItem"));
const MobileStepper_1 = tslib_1.__importDefault(require("@material-ui/core/MobileStepper"));
const AspectRatio_1 = tslib_1.__importDefault(require("@material-ui/icons/AspectRatio"));
const Code_1 = tslib_1.__importDefault(require("@material-ui/icons/Code"));
const Error_1 = tslib_1.__importDefault(require("@material-ui/icons/Error"));
const ZoomIn_1 = tslib_1.__importDefault(require("@material-ui/icons/ZoomIn"));
const ZoomOut_1 = tslib_1.__importDefault(require("@material-ui/icons/ZoomOut"));
const ZoomOutMap_1 = tslib_1.__importDefault(require("@material-ui/icons/ZoomOutMap"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
/**
 * Document widget component for modifying the zoom mode / level
 */
exports.ZoomModeWidget = () => {
    const localization = hooks_1.useLocalization();
    const viewerState = hooks_1.useViewerState();
    const zoomMenuAnchor = react_1.useRef();
    const [isZoomMenuOpened, setIsZoomMenuOpened] = react_1.useState(false);
    const openZoomMenu = react_1.useCallback(() => {
        setIsZoomMenuOpened(true);
    }, []);
    const closeZoomMenu = (newZoomMode) => {
        if (newZoomMode) {
            viewerState.updateState({ zoomMode: newZoomMode });
        }
        setIsZoomMenuOpened(false);
    };
    const zoomIn = react_1.useCallback((ev) => {
        ev.preventDefault();
        ev.stopPropagation();
        viewerState.updateState({ customZoomLevel: viewerState.customZoomLevel + 1 || 1 });
    }, [viewerState]);
    const zoomOut = react_1.useCallback((ev) => {
        ev.preventDefault();
        ev.stopPropagation();
        viewerState.updateState({ customZoomLevel: viewerState.customZoomLevel + 1 || 0 });
    }, [viewerState]);
    return (react_1.default.createElement("div", { style: { display: 'inline-block' } },
        react_1.default.createElement(IconButton_1.default, { onClick: openZoomMenu, title: localization.zoomMode, innerRef: zoomMenuAnchor }, (() => {
            switch (viewerState.zoomMode) {
                case 'custom':
                    if (viewerState.customZoomLevel > 0) {
                        return react_1.default.createElement(ZoomIn_1.default, null);
                    }
                    return react_1.default.createElement(ZoomOut_1.default, null);
                case 'fitHeight':
                    return react_1.default.createElement(Code_1.default, { style: { transform: 'rotate(90deg)' } });
                case 'fitWidth':
                    return react_1.default.createElement(Code_1.default, null);
                case 'originalSize':
                    return react_1.default.createElement(AspectRatio_1.default, null);
                case 'fit':
                    return react_1.default.createElement(ZoomOutMap_1.default, null);
                default:
                    return react_1.default.createElement(Error_1.default, null);
            }
        })()),
        react_1.default.createElement(Menu_1.default, { id: "zoom-menu", anchorEl: zoomMenuAnchor.current, open: isZoomMenuOpened, onClose: () => closeZoomMenu() },
            react_1.default.createElement(MenuItem_1.default, { onClick: () => closeZoomMenu('fit') },
                react_1.default.createElement(ZoomOutMap_1.default, null),
                " \u00A0 ",
                localization.zoomModeFit,
                ' '),
            react_1.default.createElement(MenuItem_1.default, { onClick: () => closeZoomMenu('originalSize') },
                react_1.default.createElement(AspectRatio_1.default, null),
                "\u00A0 ",
                localization.zoomModeOriginalSize,
                ' '),
            react_1.default.createElement(MenuItem_1.default, { onClick: () => closeZoomMenu('fitHeight') },
                react_1.default.createElement(Code_1.default, { style: { transform: 'rotate(90deg)' } }),
                " \u00A0 ",
                localization.zoomModeFitHeight,
                ' '),
            react_1.default.createElement(MenuItem_1.default, { onClick: () => closeZoomMenu('fitWidth') },
                react_1.default.createElement(Code_1.default, null),
                " \u00A0 ",
                localization.zoomModeFitWidth,
                ' '),
            react_1.default.createElement(Divider_1.default, { light: true }),
            "\u00A0 ",
            localization.zooomModeCustom,
            " ",
            react_1.default.createElement("br", null),
            react_1.default.createElement(MobileStepper_1.default, { variant: "progress", steps: 6, position: "static", activeStep: viewerState.customZoomLevel, nextButton: react_1.default.createElement(IconButton_1.default, { disabled: viewerState.customZoomLevel === 5, onClickCapture: zoomIn },
                    react_1.default.createElement(ZoomIn_1.default, null)), backButton: react_1.default.createElement(IconButton_1.default, { disabled: viewerState.customZoomLevel === 0, onClickCapture: zoomOut },
                    react_1.default.createElement(ZoomOut_1.default, null)) }))));
};
//# sourceMappingURL=ZoomMode.js.map