"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
exports.DocumentPermissionsContext = react_1.default.createContext({
    canEdit: false,
    canHideRedaction: false,
    canHideWatermark: false,
});
exports.DocumentPermissionsContextProvider = ({ children }) => {
    const { documentData } = hooks_1.useDocumentData();
    const api = hooks_1.useDocumentViewerApi();
    const [canEdit, setcanEdit] = react_1.useState(false);
    const [canHideRedaction, setcancanHideRedaction] = react_1.useState(false);
    const [canHideWatermark, setcanHideWatermark] = react_1.useState(false);
    react_1.useEffect(() => {
        const abortController = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                const canEditPromise = api.canEditDocument({ document: documentData, abortController });
                const cancanHideRedactionPromise = api.canHideRedaction({ document: documentData, abortController });
                const canHideWatermarkPromise = api.canHideWatermark({ document: documentData, abortController });
                const [canEditValue, cancanHideRedactionValue, canHideWatermarkValue] = yield Promise.all([
                    canEditPromise,
                    cancanHideRedactionPromise,
                    canHideWatermarkPromise,
                ]);
                setcanEdit(canEditValue);
                setcancanHideRedaction(cancanHideRedactionValue);
                setcanHideWatermark(canHideWatermarkValue);
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        }))();
    }, [api, documentData]);
    return (react_1.default.createElement(exports.DocumentPermissionsContext.Provider, { value: {
            canEdit,
            canHideRedaction,
            canHideWatermark,
        } }, children));
};
//# sourceMappingURL=document-permissions.js.map